@@ -2,6 +2,7 @@
 #define BOARD_H
 
 #include <klistview.h>
+#include <qstringlist.h>
 
 class Board : public KListView
 {
@@ -10,14 +11,21 @@ class Board : public KListView
 		Board(QWidget *parent = NULL, const char *name = NULL);
 		~Board();
 		void init(int type);
+		void init2(QString type);
 		void deleteTracks();
 		void clear();
 		void save(QString filename);
 		void load(QString filename);
+		QStringList list();
+		QString type();
+
 	public slots:
-		void slotNewTrack(QString medium, QString year, QString artist, QString title);
+		void slotNewTrack(QStringList list);
+
 	private:
 		int m_changed;
+		QString m_type;
+		QListViewItem *m_replace;
 };
 
 #endif
