@@ -2,8 +2,12 @@
 #define ENTRY_H
 
 #include <qwidget.h>
+#include <qstringlist.h>
+#include <qlist.h>
 
 class QLineEdit;
+class QVBoxLayout;
+class QGridLayout;
 
 class Entry : public QWidget
 {
@@ -11,12 +15,20 @@ class Entry : public QWidget
 	public:
 		Entry(QWidget *parent = NULL, const char *name = NULL);
 		~Entry();
+		void init(int type);
+		void init2(QString type);
+		void fill(QStringList list);
+
 	public slots:
 		void slotAccept();
+
 	signals:
-		void signalNewTrack(QString medium, QString year, QString artist, QString title);
+		void signalNewTrack(QStringList list);
+
 	private:
-		QLineEdit *edtitle, *edartist, *edmedium, *edyear;
+		QVBoxLayout *vbox;
+		QGridLayout *grid;
+		QList<QLineEdit> editlist;
 };
 
 #endif
