@@ -1,7 +1,9 @@
+#include "toplevel.h"
+#include "config.h"
+
 #include <kapp.h>
 #include <klocale.h>
 #include <kaboutdata.h>
-#include "toplevel.h"
 #include <kcmdlineargs.h>
 #include <klocale.h>
 
@@ -10,10 +12,10 @@ int main(int argc, char **argv)
 	Toplevel *top;
 	KAboutData *about;
 
-	about = new KAboutData("novinyl", I18N_NOOP("KDE Music Database"), "0.1",
+	about = new KAboutData("novinyl", I18N_NOOP("KDE Music Database"), VERSION,
 		I18N_NOOP("Small parent-friendly music management for the KDE"),
 		KAboutData::License_GPL, "Copyright (C) 2001 Josef Spillner", NULL,
-		"http://mindx.sourceforge.net", "dr_maux@users.sourceforge.net");
+		"http://mindx.sourceforge.net/novinyl", "dr_maux@users.sourceforge.net");
 	about->addAuthor("Josef Spillner", "Programming", "dr_maux@users.sourceforge.net");
 
 	KCmdLineArgs::init(argc, argv, about);
