@@ -1,5 +1,9 @@
 #include "newdb.h"
+
+#include "scheme.h"
+
 #include <klocale.h>
+
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qlabel.h>
@@ -14,8 +18,9 @@ NewDB::NewDB(QWidget *parent, const char *name)
 	QPushButton *ok, *cancel;
 
 	dbtypes = new QComboBox(this);
-	dbtypes->insertItem("Music collections (Novinyl 'classic')");
-	dbtypes->insertItem("KDE programs collection");
+	QList<QString> l = Scheme::instance()->schemes();
+	for(QString *s = l.first(); s; s = l.next())
+		dbtypes->insertItem(*s);
 
 	label = new QLabel(i18n("Please choose the appropriate database type:"), this);
 
@@ -43,6 +48,6 @@ NewDB::~NewDB()
 
 void NewDB::slotNewDB()
 {
-	emit signalNewDB(dbtypes->currentItem());
+	emit signalNewDB(dbtypes->currentText());
 }
 
