@@ -11,10 +11,13 @@ class NewDB : public QWidget
 	public:
 		NewDB(QWidget *parent = NULL, const char *name = NULL);
 		~NewDB();
+
 	public slots:
 		void slotNewDB();
+
 	signals:
-		void signalNewDB(int type);
+		void signalNewDB(QString type);
+
 	private:
 		QComboBox *dbtypes;
 };
