@@ -2,11 +2,14 @@
 #define TOPLEVEL_H
 
 #include <kmainwindow.h>
+
 #include <qstringlist.h>
 
 class Board;
 class Entry;
 class NewDB;
+class Scheme;
+class KPopupMenu;
 
 class Toplevel : public KMainWindow
 {
@@ -19,19 +22,24 @@ class Toplevel : public KMainWindow
 			menufilenew,
 			menufileopen,
 			menufilesave,
+			menufilesaveas,
 			menufilequit,
 			menuentrynew,
+			menuentrymodify,
 			menuentrydelete
 		};
 
 	public slots:
 		void slotMenu(int id);
-		void slotNewDB(int type);
+		void slotNewDB(QString type);
 
 	private:
 		Board *board;
 		Entry *entry;
 		NewDB *newdb;
+		Scheme *scheme;
+		QString m_type;
+		KPopupMenu *menu_entry;
 };
 
 #endif
